etao
====
.. image:: https://travis-ci.org/jamchamb/etao.svg?branch=master
    :target: https://travis-ci.org/jamchamb/etao
.. image:: https://badge.fury.io/py/etao.svg
    :target: https://badge.fury.io/py/etao

Simple cryptanalysis library.

Installation
------------
Install with pip::

    pip install etao

